@@ -14,6 +14,6 @@ class Batch(Base):
 
     def __repr__(self):
         """
-        Override the method to return the asset name with id
+        Override the method to return the asset name
         """
-        return f"<{Constants.BATCH_ENTITY}: {self.batch_name}_{self.id}>"
+        return f"<{Constants.BATCH_ENTITY}: {self.batch_name}>"
